@@ -150,6 +150,8 @@
 #include "token_info-5.20.0.h"
 #elif PERL_VERSION == 20 && PERL_SUBVERSION == 1
 #include "token_info-5.20.0.h"
+#elif PERL_VERSION == 20 && PERL_SUBVERSION == 2
+#include "token_info-5.20.0.h"
 #elif PERL_VERSION == 21 && PERL_SUBVERSION == 0
 #include "token_info-5.21.0.h"
 #elif PERL_VERSION == 21 && PERL_SUBVERSION == 1
@@ -162,7 +164,13 @@
 #include "token_info-5.21.4.h"
 #elif PERL_VERSION == 21 && PERL_SUBVERSION == 5
 #include "token_info-5.21.5.h"
-#elif PERL_VERSION > 21 || (PERL_VERSION == 21 && PERL_SUBVERSION > 5)
+#elif PERL_VERSION == 21 && PERL_SUBVERSION == 6
+#include "token_info-5.21.6.h"
+#elif PERL_VERSION == 21 && PERL_SUBVERSION == 7
+#include "token_info-5.21.7.h"
+#elif PERL_VERSION == 21 && PERL_SUBVERSION == 8
+#include "token_info-5.21.8.h"
+#elif PERL_VERSION > 21 || (PERL_VERSION == 21 && PERL_SUBVERSION > 8)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
